This library is intended for educational purposes and should not be used for securing sensitive information. Classical ciphers like Caesar are easily broken with modern cryptanalysis techniques.
pub use classical::*;
pub use encoding::*;
pub use utils::*;
pub use traits::*;